==> jc-1.4.0.tar.gz: gnu/java/security/provider/SHA1PRNG.h <==
// public class gnu.java.security.provider.SHA1PRNG

// class file dependencies
// @dep_class f9ed3759489b9233 gnu_java_security_provider_SHA1PRNG
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 254ca156f086a0ef java_security_SecureRandomSpi

// header file dependencies
// @dep_header java_security_SecureRandomSpi

#include "java/security/SecureRandomSpi.h"

#ifndef _JC_gnu_java_security_provider_SHA1PRNG_H_
#define _JC_gnu_java_security_provider_SHA1PRNG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$sub_refs	_jc_gnu_java_security_provider_SHA1PRNG$sub_refs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs	_jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$refs	_jc_gnu_java_security_provider_SHA1PRNG$refs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$nonrefs	_jc_gnu_java_security_provider_SHA1PRNG$nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$object	_jc_gnu_java_security_provider_SHA1PRNG$object;

typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vmethods	_jc_gnu_java_security_provider_SHA1PRNG$vmethods;
typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vtable	_jc_gnu_java_security_provider_SHA1PRNG$vtable;
typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vtype	_jc_gnu_java_security_provider_SHA1PRNG$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_provider_SHA1PRNG$method$engineGenerateSeed$3f2678c95ef54b9d(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, jint);
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$engineNextBytes$41b3d85f207b40da(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$engineSetSeed$d5670365ecc71f53(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$ensureIsSeeded$ffcf98ef7344e986(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *);
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineGenerateSeed$3f2678c95ef54b9d;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineNextBytes$41b3d85f207b40da;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineSetSeed$d5670365ecc71f53;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$ensureIsSeeded$ffcf98ef7344e986;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_SHA1PRNG$vmethods {
	_jc_byte_array	*(*engineGenerateSeed$3f2678c95ef54b9d)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, jint);
	void	(*engineNextBytes$41b3d85f207b40da)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *);
	void	(*engineSetSeed$d5670365ecc71f53)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *);
	void	(*ensureIsSeeded$ffcf98ef7344e986)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_SHA1PRNG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SecureRandomSpi$vmethods	java_security_SecureRandomSpi;
	_jc_gnu_java_security_provider_SHA1PRNG$vmethods	gnu_java_security_provider_SHA1PRNG;
};

// Vtype
struct _jc_gnu_java_security_provider_SHA1PRNG$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_SHA1PRNG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA1PRNG$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
	_jc_byte_array	*seed;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA1PRNG$refs {
    _jc_gnu_java_security_provider_SHA1PRNG$sub_refs	gnu_java_security_provider_SHA1PRNG;
    _jc_java_security_SecureRandomSpi$sub_refs	java_security_SecureRandomSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs {
	jint	seedpos;
	jint	datapos;
	jboolean	seeded;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA1PRNG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SecureRandomSpi$sub_nonrefs	java_security_SecureRandomSpi;
    _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs	gnu_java_security_provider_SHA1PRNG;
};

// Object instance structure
struct _jc_gnu_java_security_provider_SHA1PRNG$object {
	_jc_gnu_java_security_provider_SHA1PRNG$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_SHA1PRNG$vtype	*vtype;
	_jc_gnu_java_security_provider_SHA1PRNG$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_SHA1PRNG$vtype _jc_gnu_java_security_provider_SHA1PRNG$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_SHA1PRNG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_SHA1PRNG$class_object;

#endif	/* _JC_gnu_java_security_provider_SHA1PRNG_H_ */

==> jc-1.4.5.tar.gz: gnu/java/security/provider/SHA1PRNG.h <==
// public class gnu.java.security.provider.SHA1PRNG

// class file dependencies
// @dep_class f9ed3759489b9233 gnu_java_security_provider_SHA1PRNG
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 254ca156f086a0ef java_security_SecureRandomSpi

// header file dependencies
// @dep_header java_security_SecureRandomSpi

#include "java/security/SecureRandomSpi.h"

#ifndef _JC_gnu_java_security_provider_SHA1PRNG_H_
#define _JC_gnu_java_security_provider_SHA1PRNG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$sub_refs	_jc_gnu_java_security_provider_SHA1PRNG$sub_refs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs	_jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$refs	_jc_gnu_java_security_provider_SHA1PRNG$refs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$nonrefs	_jc_gnu_java_security_provider_SHA1PRNG$nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA1PRNG$object	_jc_gnu_java_security_provider_SHA1PRNG$object;

typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vmethods	_jc_gnu_java_security_provider_SHA1PRNG$vmethods;
typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vtable	_jc_gnu_java_security_provider_SHA1PRNG$vtable;
typedef const struct _jc_gnu_java_security_provider_SHA1PRNG$vtype	_jc_gnu_java_security_provider_SHA1PRNG$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_provider_SHA1PRNG$method$engineGenerateSeed$3f2678c95ef54b9d(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$engineNextBytes$41b3d85f207b40da(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$engineSetSeed$d5670365ecc71f53(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$ensureIsSeeded$ffcf98ef7344e986(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA1PRNG$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineGenerateSeed$3f2678c95ef54b9d;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineNextBytes$41b3d85f207b40da;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$engineSetSeed$d5670365ecc71f53;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$ensureIsSeeded$ffcf98ef7344e986;
extern _jc_method _jc_gnu_java_security_provider_SHA1PRNG$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_SHA1PRNG$vmethods {
	_jc_byte_array	*(*engineGenerateSeed$3f2678c95ef54b9d)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, jint) _JC_JCNI_ATTR;
	void	(*engineNextBytes$41b3d85f207b40da)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*engineSetSeed$d5670365ecc71f53)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*ensureIsSeeded$ffcf98ef7344e986)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_SHA1PRNG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_SHA1PRNG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SecureRandomSpi$vmethods	java_security_SecureRandomSpi;
	_jc_gnu_java_security_provider_SHA1PRNG$vmethods	gnu_java_security_provider_SHA1PRNG;
};

// Vtype
struct _jc_gnu_java_security_provider_SHA1PRNG$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_SHA1PRNG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA1PRNG$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
	_jc_byte_array	*seed;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA1PRNG$refs {
    _jc_gnu_java_security_provider_SHA1PRNG$sub_refs	gnu_java_security_provider_SHA1PRNG;
    _jc_java_security_SecureRandomSpi$sub_refs	java_security_SecureRandomSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs {
	jint	seedpos;
	jint	datapos;
	jboolean	seeded;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA1PRNG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SecureRandomSpi$sub_nonrefs	java_security_SecureRandomSpi;
    _jc_gnu_java_security_provider_SHA1PRNG$sub_nonrefs	gnu_java_security_provider_SHA1PRNG;
};

// Object instance structure
struct _jc_gnu_java_security_provider_SHA1PRNG$object {
	_jc_gnu_java_security_provider_SHA1PRNG$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_SHA1PRNG$vtype	*vtype;
	_jc_gnu_java_security_provider_SHA1PRNG$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_SHA1PRNG$vtype _jc_gnu_java_security_provider_SHA1PRNG$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_SHA1PRNG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_SHA1PRNG$class_object;

#endif	/* _JC_gnu_java_security_provider_SHA1PRNG_H_ */
